aboutsummaryrefslogtreecommitdiff
path: root/networking/udhcp/d6_dhcpc.c
diff options
context:
space:
mode:
Diffstat (limited to 'networking/udhcp/d6_dhcpc.c')
-rw-r--r--networking/udhcp/d6_dhcpc.c9
1 files changed, 4 insertions, 5 deletions
diff --git a/networking/udhcp/d6_dhcpc.c b/networking/udhcp/d6_dhcpc.c
index 35c99e89c..289df66ee 100644
--- a/networking/udhcp/d6_dhcpc.c
+++ b/networking/udhcp/d6_dhcpc.c
@@ -1375,13 +1375,12 @@ int udhcpc6_main(int argc UNUSED_PARAM, char **argv)
/* yah, I know, *you* say it would never happen */
timeout = INT_MAX;
continue; /* back to main loop */
- } /* if select timed out */
+ } /* if poll timed out */
- /* select() didn't timeout, something happened */
+ /* poll() didn't timeout, something happened */
/* Is it a signal? */
- /* note: udhcp_sp_read checks poll result before reading */
- switch (udhcp_sp_read(pfds)) {
+ switch (udhcp_sp_read()) {
case SIGUSR1:
client_config.first_secs = 0; /* make secs field count from 0 */
already_waited_sec = 0;
@@ -1416,7 +1415,7 @@ int udhcpc6_main(int argc UNUSED_PARAM, char **argv)
}
/* Is it a packet? */
- if (listen_mode == LISTEN_NONE || !pfds[1].revents)
+ if (!pfds[1].revents)
continue; /* no */
{